#ifndef OVERWRITEBOX_H
#define OVERWRITEBOX_H


#include "DialogBox.h"

// Return values
enum ConfirmOverWriteBoxReturn {
    MBOX_CLICKED_OVERWRITE    = 1,
    MBOX_CLICKED_OVERWRITE_ALL= 2,
    MBOX_CLICKED_SKIP         = 3,
    MBOX_CLICKED_SKIP_ALL     = 4,
};


// Message box
class FXAPI ConfirmOverWriteBox : public DialogBox
{
    FXDECLARE(ConfirmOverWriteBox)
protected:
    ConfirmOverWriteBox()
    {}
    ConfirmOverWriteBox(const ConfirmOverWriteBox&)
    {}
public:
    long onCmdClicked(FXObject*,FXSelector,void*);
public:
    enum{
        ID_CLICKED_OVERWRITE=DialogBox::ID_LAST,
        ID_CLICKED_OVERWRITE_ALL,
        ID_CLICKED_SKIP,
        ID_CLICKED_SKIP_ALL,
        ID_LAST
    };
public:
    ConfirmOverWriteBox(FXWindow *win,const FXString& name,const FXString& text,FXuint opts=DECOR_TITLE|DECOR_BORDER,FXint x=0,FXint y=0);
};

#endif
